@@ -1,7 +1,5 @@
-context("Rd: section")
-
 test_that("warn if forgotton colom", {
-  expect_warning(
+  expect_snapshot_warning(
     roc_proc_text(rd_roclet(), "
       #' Foo
       #'
@@ -9,12 +7,10 @@ test_that("warn if forgotton colom", {
       #' Here.
       #' There
       foo <- function(x = '%') x
-    "),
-    "Section title spans multiple lines"
+    ")
   )
 })
 
-
 test_that("@section-s with identical titles are merged", {
   out <- roc_proc_text(rd_roclet(), "
     #' Foo
@@ -32,8 +28,8 @@ test_that("@section-s with identical titles are merged", {
   ")[[1]]
 
   expect_equal(
-    out$get_field("section"),
-    roxy_field_section(
+    out$get_section("section"),
+    rd_section_section(
       c("Haz dox", "TL", "RT"),
       c(" Here.\n\n\n  Got news.", " DR.", " FM.")
     )
@@ -54,7 +50,7 @@ test_that("@section-s with different titles are kept as they are", {
   ")[[1]]
 
   expect_equal(
-    out$get_field("section"),
-    roxy_field_section(LETTERS[1:3], c(" 1", " 2", " 3"))
+    out$get_section("section"),
+    rd_section_section(LETTERS[1:3], c(" 1", " 2", " 3"))
   )
 })
